@@ -77,6 +77,7 @@ PROFILES = [
             CharEncodingConverter(id='latin1',label='Convert from Latin-1 (iso-8859-1)',charset='iso-8859-1'),
             CharEncodingConverter(id='latin9',label='Convert from Latin-9 (iso-8859-15)',charset='iso-8859-15'),
             multi=True,
+            extension='.txt',
         ),
         OutputTemplate('mainoutput', TadpoleFormat,"Frog Columned Output (legacy)",  #named 'mainoutput' for legacy reasons
             SetMetaField('tokenisation','yes'),
@@ -90,20 +91,23 @@ PROFILES = [
             ParameterCondition(skip_contains='p',
                 then=SetMetaField('parsing','no'),
                 otherwise=SetMetaField('parsing','yes'),
-            ),            
+            ),
+            removeextensions=['.txt','.xml'],            
             extension='.frog.out',
             copymetadata=True,
             multi=True,
         ),
         OutputTemplate('foliaoutput', FoLiAXMLFormat,"FoLiA Document",
             FoLiAViewer(), 
+            removeextensions=['.txt'],
             extension='.xml',
             copymetadata=True,
             multi=True,
         ),        
     ),
     Profile(
-        InputTemplate('foliainput', FoLiAXMLFormat,"FoLiA XML document", 
+        InputTemplate('foliainput', FoLiAXMLFormat,"FoLiA XML document",
+            extension='.xml', 
             multi=True,
         ),
         OutputTemplate('mainoutput', TadpoleFormat,"Frog Columned Output (legacy)",  #named 'mainoutput' for legacy reasons
@@ -119,12 +123,14 @@ PROFILES = [
                 then=SetMetaField('parsing','no'),
                 otherwise=SetMetaField('parsing','yes'),
             ),            
+            removeextensions=['.xml','.txt'],
             extension='.frog.out',
             copymetadata=True,
             multi=True,
         ),
-        OutputTemplate('foliaoutput', FoLiAXMLFormat,"FoLiA Document",
-            FoLiAViewer(), 
+        OutputTemplate('foliaoutput', FoLiAXMLFormat,"FoLiA Document",                    
+            FoLiAViewer(),
+            extension='.xml', 
             copymetadata=True,
             multi=True,
         ),        
